@@ -11,26 +11,21 @@
 #' @keywords internal
 #' @importFrom network %v%<- as.network
 #'
-#' @importFrom ggnetwork ggnetwork geom_edges geom_nodes geom_nodetext
+#' @importFrom ggraph ggraph geom_edge_fan geom_node_point geom_node_text create_layout circle
 #' @importFrom dplyr distinct %>% rename mutate arrange id
-#' @importFrom ggplot2 scale_x_continuous
-
+# @importFrom ggplot2 scale_x_continuous
 
 drawGraph <- function(Elegans, nodeinfo, title, species, ont, org){
-  xend <- yend <- level <- label <- NULL
+  level <- from <- label <- NULL
 
   if(toupper(ont) == "BP"){
     y <- xx.ch
-    jump <- 0.03
   }else if(toupper(ont) == "MF"){
     y <- xx.ch1
-    jump <- 0.02
   }else if(toupper(ont) == "CC"){
     y <- xx.ch2
-    jump <- 0.02
   }
 
-
   # Preprocess data
   title <- title
   edges <- unique(as.data.frame(Elegans))
@@ -40,7 +35,6 @@ drawGraph <- function(Elegans, nodeinfo, title, species, ont, org){
   num <- max(unlist(levels))
 
   # Count total number of terms
-
   GOTotal <- lapply(1:length(species), function(x){
     length(species[[as.character(x)]])})
   GOTotal <- unlist(GOTotal)
@@ -102,13 +96,11 @@ drawGraph <- function(Elegans, nodeinfo, title, species, ont, org){
 
   layout <- do.call(rbind, traces)
 
-  net <- ggnetwork(n, layout = layout)
-  net$level <- factor(net$level, levels=c(1:max(tags)))
-
-  # arrange the text based on the levels
+  #a_net <- graph_from_data_frame(edges)
+  a_net <- create_layout(n, layout = layout)
+  a_net$name <- as.character(nodes$label)
 
   # Connection between nodes
-
   a <- nodeinfo
   connect <- a[,2]
   storeCount <- matrix(0, nrow = dim(a)[1],ncol = dim(a)[2])
@@ -132,29 +124,27 @@ drawGraph <- function(Elegans, nodeinfo, title, species, ont, org){
   storeCount <- as.data.frame(storeCount)
   colnames(storeCount) <- c("a","b","c")
 
-  ## the coordinates for annotating text
-  ind <- sort(unique(as.integer(net$level)),index.return = TRUE)$ix
-  y.ind <- unique(net$y)
-  # Plot network
 
-  p <- ggplot(net, aes(x = x, y = y, xend = xend, yend = yend))  + geom_hline(yintercept = unique(net$y), color = "white", size=0.5) +
-    geom_edges(aes(color = level), arrow = arrow(length = unit(3, "pt"), type = "closed"), curvature = 0.2) +
-    geom_nodes(aes(color = level, size = 10, stroke = 2.7)) +
-    #geom_nodes(size = 3, shape = 21, color = "steelblue") +
-    geom_nodetext(aes(label = label), color= "#3f2a1d", fontface = "bold", size = 3.5) +
+  # Plot network
+  p <- ggraph(a_net) + ggplot2::geom_hline(yintercept = unique(a_net$y), color = "white", size=0.5, show.legend = TRUE ) +
+    ggplot2::geom_vline(xintercept = c(0, 0.5,1), color = "white", size=0.5) +
+    geom_edge_fan(aes(color = as.factor(from)),arrow = arrow(length = unit(3, "pt"), type = "closed"),
+                  start_cap = circle(3, 'mm'), end_cap = circle(3, 'mm'),show.legend = TRUE) +
+    geom_node_point(aes(colour = as.factor(tags), size = 10, stroke = 2.7)) +
+    geom_node_text(aes(label = nodes$label), color= "#3f2a1d", fontface = "bold", size = 3.5) +
     theme(plot.title = element_text(face = "bold", size = rel(1.1), hjust = 0.5), plot.caption = element_blank(),
           axis.ticks.y =element_blank(),
           axis.title = element_blank(),
           axis.text.x = element_text(size = 10, face = "bold"),
-          axis.text.y = element_blank(),legend.position = "none",panel.grid.minor.y = element_blank(),
+          axis.text.y = element_blank(),legend.position = "none", panel.grid.minor.y = element_blank(),
           panel.grid.minor.x = element_blank(),
-          panel.grid.major.y = element_blank()) + labs(caption = paste("Visualization of the reduced GO DAG for", tolower(org), sep = " ")) +
-    scale_x_continuous(limits = c(-0.2,2.3),breaks=c(0,0.5,1),labels = c("JN","RN","LN")) +
-    #scale_x_discrete(breaks=c("0","0.5","1"), labels=c("JN", "RN", "LN"))  +
-    guides(size = F) + annotate("text", x = 1.2, y = y.ind[ind] + jump , label = paste("L", 0:(max(tags)-1), ": ", "   "), fontface = 2, hjust = 0)+
-    annotate("text", x = 1.4, y = y.ind[ind] + jump, label = paste("J = ", storeCount$a[1:max(tags)], sep = ""), hjust = 0) +
-    annotate("text", x = 1.7, y.ind[ind] + jump, label = paste("R = ", storeCount$b[1:max(tags)], sep = ""), hjust = 0) +
-    annotate("text", x = 2.0, y.ind[ind] + jump, label = paste("L = ", storeCount$c[1:max(tags)], sep = ""), hjust = 0)
+          panel.grid.major.y = element_blank()) +
+    scale_x_continuous(limits = c(-0.2,2.3),breaks=c(0,0.5,1),labels = c("JN","RN","LN")) +  guides(size = "none") +
+    annotate("text", x = 1.2, y = unique(a_net$y)  , label = paste("L", 0:(max(tags)-1), ": ", "   "), fontface = 2, hjust = 0) +
+    annotate("text", x = 1.4, y = unique(a_net$y), label = paste("J = ", storeCount$a[1:max(tags)], sep = ""), hjust = 0) +
+    annotate("text", x = 1.7, unique(a_net$y), label = paste("R = ", storeCount$b[1:max(tags)], sep = ""), hjust = 0) +
+    annotate("text", x = 2.0, unique(a_net$y), label = paste("L = ", storeCount$c[1:max(tags)], sep = ""), hjust = 0)
+
 
   return(p)
 
@@ -165,3 +155,6 @@ drawGraph <- function(Elegans, nodeinfo, title, species, ont, org){
 
 
 
+
+
+
